@@ -38,7 +38,7 @@ __all__ = [
     'asc', 'desc', 'Count', 'Max', 'Min', 'Sum', 'Q', 'Field', 'CharField', 'TextField',
     'DateTimeField', 'BooleanField', 'DecimalField', 'FloatField', 'IntegerField',
     'PrimaryKeyField', 'ForeignKeyField', 'DoubleField', 'BigIntegerField', 'Model',
-    'filter_query', 'annotate_query', 'F', 'R',
+    'filter_query', 'annotate_query', 'F', 'R', 'DateField', 'TimeField',
 ]
 
 class ImproperlyConfigured(Exception):
@@ -216,7 +216,7 @@ class PostgresqlAdapter(BaseAdapter):
                 model._meta.pk_sequence))
         else:
             cursor.execute("SELECT CURRVAL('\"%s_%s_seq\"')" % (
-                model._meta.db_table, model._meta.pk_name))
+                model._meta.db_table, model._meta.pk_col))
         return cursor.fetchone()[0]
 
 
@@ -538,7 +538,7 @@ class MySQLDatabase(Database):
             'constraint': self.quote_name(constraint),
             'field': self.quote_name(field.db_column),
             'to': self.quote_name(field.to._meta.db_table),
-            'to_field': self.quote_name(field.to._meta.pk_name),
+            'to_field': self.quote_name(field.to._meta.pk_col),
             'cascade': ' ON DELETE CASCADE' if field.cascade else '',
         }
 
@@ -957,13 +957,14 @@ class BaseQuery(object):
     def lookup_cast(self, lookup, value):
         return self.database.adapter.lookup_cast(lookup, value)
 
-    def parse_query_args(self, model, **query):
+    def parse_query_args(self, _model, **query):
         """
         Parse out and normalize clauses in a query.  The query is composed of
         various column+lookup-type/value pairs.  Validates that the lookups
         are valid and returns a list of lookup tuples that have the form:
         (field name, (operation, value))
         """
+        model = _model
         parsed = []
         for lhs, rhs in query.iteritems():
             if self.query_separator in lhs:
@@ -1095,10 +1096,10 @@ class BaseQuery(object):
             field = from_model._meta.get_related_field_for_model(model, on)
             if field:
                 left_field = field.db_column
-                right_field = model._meta.pk_name
+                right_field = model._meta.pk_col
             else:
                 field = from_model._meta.get_reverse_related_field_for_model(model, on)
-                left_field = from_model._meta.pk_name
+                left_field = from_model._meta.pk_col
                 right_field = field.db_column
 
             if join_type is None:
@@ -1335,9 +1336,9 @@ class SelectQuery(BaseQuery):
         clone._limit = clone._offset = None
 
         if clone.use_aliases():
-            clone.query = 'COUNT(t1.%s)' % (clone.model._meta.pk_name)
+            clone.query = 'COUNT(t1.%s)' % (clone.model._meta.pk_col)
         else:
-            clone.query = 'COUNT(%s)' % (clone.model._meta.pk_name)
+            clone.query = 'COUNT(%s)' % (clone.model._meta.pk_col)
 
         res = clone.database.execute(*clone.sql())
 
@@ -1449,7 +1450,7 @@ class SelectQuery(BaseQuery):
             # convert '*' and primary key lookups
             if q == '*':
                 q = {self.model: self.model._meta.get_field_names()}
-            elif q == self.model._meta.pk_name:
+            elif q in (self.model._meta.pk_col, self.model._meta.pk_name):
                 q = {self.model: [self.model._meta.pk_name]}
             else:
                 return q, []
@@ -1600,9 +1601,9 @@ class SelectQuery(BaseQuery):
 
 
 class UpdateQuery(BaseQuery):
-    def __init__(self, model, **kwargs):
+    def __init__(self, _model, **kwargs):
         self.update_query = kwargs
-        super(UpdateQuery, self).__init__(model)
+        super(UpdateQuery, self).__init__(_model)
 
     def clone(self):
         query = UpdateQuery(self.model, **self.update_query)
@@ -1708,9 +1709,9 @@ class DeleteQuery(BaseQuery):
 
 
 class InsertQuery(BaseQuery):
-    def __init__(self, model, **kwargs):
+    def __init__(self, _model, **kwargs):
         self.insert_query = kwargs
-        super(InsertQuery, self).__init__(model)
+        super(InsertQuery, self).__init__(_model)
 
     def parse_insert(self):
         cols = []
@@ -1939,7 +1940,7 @@ class VarCharColumn(Column):
         return {'max_length': 255}
 
     def db_value(self, value):
-        value = value or ''
+        value = unicode(value or '')
         return value[:self.attributes['max_length']]
 
 
@@ -1960,8 +1961,8 @@ class DateTimeColumn(Column):
             match = self.dt_re.match(value)
             if match:
                 value, usec = match.groups()
-                usec = usec and int(usec) or 0
-                return datetime.datetime(*time.strptime(value, '%Y-%m-%d %H:%M:%S')[:6], microsecond=usec)
+                kwargs = dict(microsecond=usec and int(usec) or 0)
+                return datetime.datetime(*time.strptime(value, '%Y-%m-%d %H:%M:%S')[:6], **kwargs)
             elif self.dt_bare_re.match(value):
                 return datetime.datetime(*time.strptime(value, '%Y-%m-%d')[:3])
         return value
@@ -1989,8 +1990,8 @@ class TimeColumn(Column):
             match = self.time_re.match(value)
             if match:
                 value, usec = match.groups()
-                usec = usec and int(usec) or 0
-                return datetime.time(*time.strptime(value, '%H:%M:%S')[3:6], microsecond=usec)
+                kwargs = dict(microsecond=usec and int(usec) or 0)
+                return datetime.time(*time.strptime(value, '%H:%M:%S')[3:6], **kwargs)
         elif isinstance(value, datetime.datetime):
             return value.time()
         return value
@@ -2318,7 +2319,7 @@ class ForeignKeyField(IntegerField):
         # need to update the attributes after the class has been built
         self.attributes.update({
             'to_table': self.to._meta.db_table,
-            'to_pk': self.to._meta.pk_name,
+            'to_pk': self.to._meta.pk_col,
         })
         self.column = self.get_column()
 
@@ -2458,13 +2459,14 @@ class BaseModel(type):
         if _meta.pk_sequence and _meta.database.adapter.sequence_support:
             pk_col.attributes['nextval'] = " default nextval('%s')" % _meta.pk_sequence
 
+        _meta.pk_col = pk_field.db_column
         _meta.auto_increment = isinstance(pk_col, PrimaryKeyColumn)
 
         for field in _meta.fields.values():
             field.class_prepared()
 
         if hasattr(cls, '__unicode__'):
-            setattr(cls, '__repr__', lambda self: '<%s: %s>' % (
+            setattr(cls, '__repr__', lambda self: '<%s: %r>' % (
                 _meta.model_name, self.__unicode__()))
 
         exception_class = type('%sDoesNotExist' % _meta.model_name, (DoesNotExist,), {})
